@@ -95,7 +95,8 @@ checkArgs <- function(
         "thresholdingEst", "sampleCovEst", "bandingEst",
         "taperingEst", "nlShrinkLWEst",
         "denseLinearShrinkEst", "scadEst", "poetEst", "robustPoetEst",
-        "adaptiveLassoEst"
+        "adaptiveLassoEst", "spikedOperatorShrinkEst",
+        "spikedFrobeniusShrinkEst", "spikedSteinShrinkEst"
       ) == TRUE
     ),
     msg = "Only estimators implemented in the cvCovEst package can be used."
@@ -178,6 +179,62 @@ checkArgs <- function(
       all(rlang::is_bare_numeric(estimator_params$adaptiveLassoEst$n)) == TRUE
     )
   }
+  if ("spikedOperatorShrinkEst" %in% estimators) {
+    assertthat::assert_that(
+      all(estimator_params$spikedOperatorShrinkEst$p_n_ratio > 0) == TRUE,
+      all(estimator_params$spikedOperatorShrinkEst$p_n_ratio < 1) == TRUE,
+      all(is.null(estimator_params$spikedOperatorShrinkEst$num_spikes) |
+          rlang::is_integer(estimator_params$spikedOperatorShrinkEst$num_spikes)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedOperatorShrinkEst$num_spikes) |
+            estimator_params$spikedOperatorShrinkEst$num_spikes >= 0
+      ) == TRUE,
+      all(is.null(estimator_params$spikedOperatorShrinkEst$noise) |
+          rlang::is_bare_numeric(estimator_params$spikedOperatorShrinkEst$noise)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedOperatorShrinkEst$noise) |
+          estimator_params$spikedOperatorShrinkEst$noise > 0
+      ) == TRUE
+    )
+  }
+  if ("spikedFrobeniusShrinkEst" %in% estimators) {
+    assertthat::assert_that(
+      all(estimator_params$spikedFrobeniusShrinkEst$p_n_ratio > 0) == TRUE,
+      all(estimator_params$spikedFrobeniusShrinkEst$p_n_ratio < 1) == TRUE,
+      all(
+        is.null(estimator_params$spikedFrobeniusShrinkEst$num_spikes) |
+        rlang::is_integer(estimator_params$spikedFrobeniusShrinkEst$num_spikes)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedFrobeniusShrinkEst$num_spikes) |
+          estimator_params$spikedFrobeniusShrinkEst$num_spikes >= 0
+      ) == TRUE,
+      all(
+        is.null(estimator_params$spikedFrobeniusShrinkEst$noise) |
+        rlang::is_bare_numeric(estimator_params$spikedFrobeniusShrinkEst$noise)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedFrobeniusShrinkEst$noise) |
+          estimator_params$spikedFrobeniusShrinkEst$noise > 0
+      ) == TRUE
+    )
+  }
+  if ("spikedSteinShrinkEst" %in% estimators) {
+    assertthat::assert_that(
+      all(estimator_params$spikedSteinShrinkEst$p_n_ratio > 0) == TRUE,
+      all(estimator_params$spikedSteinShrinkEst$p_n_ratio < 1) == TRUE,
+      all(is.null(estimator_params$spikedSteinShrinkEst$num_spikes) |
+          rlang::is_integer(estimator_params$spikedSteinShrinkEst$num_spikes)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedSteinShrinkEst$num_spikes) |
+          estimator_params$spikedSteinShrinkEst$num_spikes >= 0
+      ) == TRUE,
+      all(is.null(estimator_params$spikedSteinShrinkEst$noise) |
+          rlang::is_bare_numeric(estimator_params$spikedSteinShrinkEst$noise)
+      ) == TRUE,
+      all(is.null(estimator_params$spikedSteinShrinkEst$noise) |
+          estimator_params$spikedSteinShrinkEst$noise > 0
+      ) == TRUE
+    )
+  }
 
   # assert that cv scheme is supported and well defined
   assertthat::assert_that(
