@@ -8,12 +8,14 @@ Sigma <- matrix(0.5, nrow = 50, ncol = 50) + diag(0.5, nrow = 50)
 # sample 200 observations from multivariate normal with mean = 0, var = Sigma
 dat <- mvrnorm(n = 200, mu = rep(0, 50), Sigma = Sigma)
 
-# define the arguments as they appear inside cvCoveEst
+# define the arguments as they appear inside cvCovEst
 estimators <- rlang::expr(c(
   linearShrinkEst, thresholdingEst, sampleCovEst,
   linearShrinkLWEst, bandingEst, taperingEst,
   nlShrinkLWEst, denseLinearShrinkEst, scadEst,
-  poetEst, robustPoetEst, adaptiveLassoEst
+  poetEst, robustPoetEst, adaptiveLassoEst,
+  spikedOperatorShrinkEst, spikedFrobeniusShrinkEst,
+  spikedSteinShrinkEst
 ))
 estimator_params <- list(
   linearShrinkEst = list(alpha = c(0.1, 0.9)),
@@ -22,11 +24,20 @@ estimator_params <- list(
   taperingEst = list(k = c(2L, 6L)),
   scadEst = list(lambda = c(0.1, 0.2)),
   poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
+  adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
   robustPoetEst = list(
     lambda = c(0.1, 0.2), k = c(1L, 3L),
     var_est = "sample"
   ),
-  adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+  spikedOperatorShrinkEst = list(
+    p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L), noise = c(NULL, 0.5)
+  ),
+  spikedFrobeniusShrinkEst = list(
+    p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L), noise = c(NULL, 0.5)
+  ),
+  spikedSteinShrinkEst = list(
+    p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L), noise = c(NULL, 0.5)
+  )
 )
 cv_loss <- rlang::expr(cvFrobeniusLoss)
 cv_scheme <- "mc"
@@ -173,7 +184,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -193,7 +220,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -213,7 +256,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -233,7 +292,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -253,7 +328,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -273,7 +364,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2.1, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -293,7 +400,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(-2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -313,7 +436,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(3L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -333,7 +472,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -353,7 +508,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -373,7 +544,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = c(0.1, 0.2)),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -393,7 +580,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = -0.1),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -413,7 +616,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = "a"),
       poetEst = list(lambda = c(0.1, 0.2), k = c(1L, 2L, 3L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -433,7 +652,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = 0.1),
       poetEst = list(lambda = -0.1, k = c(1L, 2L)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -453,7 +688,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = 0.1),
       poetEst = list(lambda = 0.1, k = c(1.1, 2)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -473,7 +724,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = 0.1),
       poetEst = list(lambda = 0.1, k = c(1, 2)),
-      adaptiveLassoEst = list(lambda = -0.1, n = 0)
+      adaptiveLassoEst = list(lambda = -0.1, n = 0),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -493,7 +760,23 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = 0.1),
       poetEst = list(lambda = 0.1, k = c(1, 2)),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -517,7 +800,19 @@ test_that("Only reasonable hyperparameters pass checks", {
         lambda = 0.1, k = c(1L, 2L),
         var_est = c("samp", "huber")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -541,7 +836,19 @@ test_that("Only reasonable hyperparameters pass checks", {
         lambda = "a", k = c(1L, 2L),
         var_est = c("mad", "huber")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -565,7 +872,19 @@ test_that("Only reasonable hyperparameters pass checks", {
         lambda = 0.1, k = c(1.1, 2L),
         var_est = c("mad", "huber")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -585,7 +904,131 @@ test_that("Only reasonable hyperparameters pass checks", {
       taperingEst = list(k = c(2L, 6L)),
       scadEst = list(lambda = 0.1),
       poetEst = list(lambda = 0.1, k = c(1, 2)),
-      adaptiveLassoEst = list(lambda = "a", n = 0)
+      adaptiveLassoEst = list(lambda = "a", n = 0),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
+    ),
+    cv_loss = cv_loss,
+    cv_scheme = cv_scheme,
+    mc_split = mc_split,
+    v_folds = v_folds,
+    center = center,
+    scale = scale,
+    parallel = parallel
+  ))
+  expect_error(checkArgs(
+    dat = dat,
+    estimators = estimators,
+    estimator_params = list(
+      linearShrinkEst = list(alpha = c(0.1, 0.9)),
+      thresholdingEst = list(gamma = c(0.2, 2)),
+      bandingEst = list(k = c(1L, 5L)),
+      taperingEst = list(k = c(2L, 6L)),
+      scadEst = list(lambda = 0.1),
+      poetEst = list(lambda = 0.1, k = c(1, 2)),
+      adaptiveLassoEst = list(lambda = 0.5, n = 0),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(-1, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
+    ),
+    cv_loss = cv_loss,
+    cv_scheme = cv_scheme,
+    mc_split = mc_split,
+    v_folds = v_folds,
+    center = center,
+    scale = scale,
+    parallel = parallel
+  ))
+  expect_error(checkArgs(
+    dat = dat,
+    estimators = estimators,
+    estimator_params = list(
+      linearShrinkEst = list(alpha = c(0.1, 0.9)),
+      thresholdingEst = list(gamma = c(0.2, 2)),
+      bandingEst = list(k = c(1L, 5L)),
+      taperingEst = list(k = c(2L, 6L)),
+      scadEst = list(lambda = 0.1),
+      poetEst = list(lambda = 0.1, k = c(1, 2)),
+      adaptiveLassoEst = list(lambda = 0.5, n = 0),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.1, 0.8), num_spikes = c(NULL, 1L, 2.5),
+        noise = c(NULL, 0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
+    ),
+    cv_loss = cv_loss,
+    cv_scheme = cv_scheme,
+    mc_split = mc_split,
+    v_folds = v_folds,
+    center = center,
+    scale = scale,
+    parallel = parallel
+  ))
+  expect_error(checkArgs(
+    dat = dat,
+    estimators = estimators,
+    estimator_params = list(
+      linearShrinkEst = list(alpha = c(0.1, 0.9)),
+      thresholdingEst = list(gamma = c(0.2, 2)),
+      bandingEst = list(k = c(1L, 5L)),
+      taperingEst = list(k = c(2L, 6L)),
+      scadEst = list(lambda = 0.1),
+      poetEst = list(lambda = 0.1, k = c(1, 2)),
+      adaptiveLassoEst = list(lambda = 0.5, n = 0),
+      robustPoetEst = list(
+        lambda = c(0.1, 0.2), k = c(1L, 3L),
+        var_est = "sample"
+      ),
+      spikedOperatorShrinkEst = list(
+        p_n_ratio = c(0.1, 0.8), num_spikes = c(NULL, 1L),
+        noise = c(NULL, -0.5)
+      ),
+      spikedFrobeniusShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      ),
+      spikedSteinShrinkEst = list(
+        p_n_ratio = c(0.5, 0.8), num_spikes = c(NULL, 1L, 2L),
+        noise = c(NULL, 0.5)
+      )
     ),
     cv_loss = cv_loss,
     cv_scheme = cv_scheme,
@@ -793,7 +1236,7 @@ test_that("checkArgs works well in cvCovEst Function", {
       linearShrinkEst, linearShrinkLWEst,
       thresholdingEst, sampleCovEst, bandingEst,
       taperingEst, nlShrinkLWEst, denseLinearShrinkEst,
-      scadEst, poetEst, adaptiveLassoEst
+      scadEst, poetEst, adaptiveLassoEst, spikedOperatorShrinkEst
     ),
     estimator_params = list(
       linearShrinkEst = list(alpha = c(0.1, 0.9)),
@@ -806,7 +1249,8 @@ test_that("checkArgs works well in cvCovEst Function", {
         lambda = c(0.1, 0.2), k = c(3L, 4L),
         var_est = c("sample", "mad")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(p_n_ratio = c(0.5, 0.8))
     ),
     cv_loss = cvFrobeniusLoss, cv_scheme = "v_fold",
     mc_split = 0.5, v_folds = 5,
@@ -818,7 +1262,7 @@ test_that("checkArgs works well in cvCovEst Function", {
       linearShrinkEst, linearShrinkLWEst,
       thresholdingEst, sampleCovEst, bandingEst,
       taperingEst, nlShrinkLWEst, denseLinearShrinkEst,
-      scadEst, poetEst, adaptiveLassoEst
+      scadEst, poetEst, adaptiveLassoEst, spikedOperatorShrinkEst
     ),
     estimator_params = list(
       linearShrinkEst = list(alpha = c(0.1, 0.9)),
@@ -831,7 +1275,8 @@ test_that("checkArgs works well in cvCovEst Function", {
         lambda = c(0.1, 0.2), k = c(3L, 4L),
         var_est = c("sample", "mad")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(p_n_ratio = c(0.5, 0.8))
     ),
     cv_loss = cvMatrixFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
@@ -843,7 +1288,7 @@ test_that("checkArgs works well in cvCovEst Function", {
       linearShrinkEst, linearShrinkLWEst,
       thresholdingEst, sampleCovEst, bandingEst,
       taperingEst, nlShrinkLWEst, denseLinearShrinkEst,
-      scadEst, poetEst, adaptiveLassoEst
+      scadEst, poetEst, adaptiveLassoEst, spikedOperatorShrinkEst
     ),
     estimator_params = list(
       linearShrinkEst = list(alpha = c(0.1, 0.9)),
@@ -856,7 +1301,8 @@ test_that("checkArgs works well in cvCovEst Function", {
         lambda = c(0.1, 0.2), k = c(3L, 4L),
         var_est = c("sample", "mad")
       ),
-      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5))
+      adaptiveLassoEst = list(lambda = c(0, 0.5), n = c(0, 0.5)),
+      spikedOperatorShrinkEst = list(p_n_ratio = c(0.5, 0.8))
     ),
     cv_loss = cvScaledMatrixFrobeniusLoss, cv_scheme = "mc",
     mc_split = 0.5, v_folds = 5,
